<?php

namespace Drupal\remote_image\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Remote image formatter which also displays the metadata like width/height.
 *
 * @FieldFormatter(
 *   id = "remote_image_metadata",
 *   label = @Translation("Remote Image with metadata"),
 *   field_types = {
 *     "remote_image"
 *   }
 * )
 */
class RemoteImageWithMetadataFormatter extends RemoteImageFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);

    foreach ($items as $delta => $item) {
      $image = $elements[$delta];
      if (empty($image['#width']) && empty($image['#height'])) {
        $width = $height = $this->t('Original image size');
      }
      elseif (!empty($image['#width'])) {
        $width = $image['#width'];
        $height = $this->t('Keeping the aspect ratio according to the width value');
      }
      elseif (!empty($image['#height'])) {
        $height = $image['#height'];
        $width = $this->t('Keeping the aspect ratio according to the height value');
      }

      $element = [
        'image' => [
          '#prefix' => '<div class="field__label">' . $this->t('Image') . '</div>',
          'image' => $image,
        ],
        'width' => [
          '#prefix' => '<div class="field__label">' . $this->t('Width') . '</div>',
          '#markup' => $width,
        ],
        'height' => [
          '#prefix' => '<div class="field__label">' . $this->t('Height') . '</div>',
          '#markup' => $height,
        ],
      ];

      if (isset($image['#title'])) {
        $element['title'] = [
          '#prefix' => '<div class="field__label">' . $this->t('Title') . '</div>',
          '#markup' => $image['#title'],
        ];
      }
      if (isset($image['#alt'])) {
        $element['alt'] = [
          '#prefix' => '<div class="field__label">' . $this->t('Alt') . '</div>',
          '#markup' => $image['#alt'],
        ];
      }
      $elements[$delta] = $element;
    }

    return $elements;
  }

}
